@@ -1,21 +1,8 @@
 /*
-   Copyright (C) 2003-2005 George Staikos <staikos@kde.org>
-   Copyright (C) 2005 Isaac Clerencia <isaac@warp.es>
+    SPDX-FileCopyrightText: 2003-2005 George Staikos <staikos@kde.org>
+    SPDX-FileCopyrightText: 2005 Isaac Clerencia <isaac@warp.es>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef ALLYOURBASE_H
@@ -46,7 +33,7 @@ class KWalletEntryItem : public QTreeWidgetItem
 {
 public:
     KWalletEntryItem(KWallet::Wallet *w, QTreeWidgetItem *parent, const QString &ename);
-    virtual ~KWalletEntryItem();
+    ~KWalletEntryItem() override;
 
     const QString &name() const
     {
@@ -68,7 +55,7 @@ class KWalletContainerItem : public QTreeWidgetItem
 {
 public:
     KWalletContainerItem(QTreeWidgetItem *parent, const QString &name, KWallet::Wallet::EntryType entryType);
-    virtual ~KWalletContainerItem();
+    ~KWalletContainerItem() override;
 
 public:
     KWallet::Wallet::EntryType entryType();
@@ -83,7 +70,7 @@ class KWalletFolderItem : public QTreeWidgetItem
 {
 public:
     KWalletFolderItem(KWallet::Wallet *w, QTreeWidget *parent, const QString &name, int entries);
-    virtual ~KWalletFolderItem();
+    ~KWalletFolderItem() override;
 
     virtual bool acceptDrop(const QMimeData *mime) const;
 
@@ -109,7 +96,7 @@ class KWalletEntryList : public QTreeWidget
 
 public:
     explicit KWalletEntryList(QWidget *parent, const QString &name = QString());
-    virtual ~KWalletEntryList();
+    ~KWalletEntryList() override;
 
     bool existsFolder(const QString &name);
     KWalletFolderItem *getFolder(const QString &name);
@@ -141,7 +128,7 @@ class KWalletItem : public QListWidgetItem
 {
 public:
     KWalletItem(QListWidget *parent, const QString &walletName);
-    virtual ~KWalletItem();
+    ~KWalletItem() override;
 
     void setOpen(bool state);
 
